# Just call a function .pysangkom()

## Warning⚠️
EN: This library is useless and uses a lot of CPU and RAM. Use it when you want to crash your own computer.

TH: Library นี้ไม่มีประโยชน์ใดๆ และใช้ CPU และ RAM ค่อนข้างมาก ควรใช้เมื่อต้องการพังคอมตัวเองทิ้งจะดีที่สุดs

## How to use
<pre>
from pysangkom.forkyou import pysangkom

call = pysangkom.pysangkom()
</pre>